<?php

/**
 * The file that defines the Notification component
 *
 * @link       https://www.swascan.com
 * @since      0.9
 *
 * @package    GDPR-WP
 * @subpackage GDPR-WP/includes
 */

/**
 * The Notification plugin class.
 *
 * This is used to help us notify users of changes they've made to their profile.
 *
 *
 * @since      0.9
 * @package    GDPR-WP
 * @subpackage GDPR-WP/includes
 * @author     Fernando Claussen <fernandoclaussen@gmail.com>
 */
class GDPR_WP_Notification {

	/**
	 * The template class instance.
	 *
	 * @since    0.9
	 * @access   protected
	 * @var      string    $template    The template class instance.
	 */
	protected $template;

	/**
	 * Define the core functionality of the plugin.
	 *
	 * Set the plugin name and the plugin version that can be used throughout the plugin.
	 *
	 * @since    0.9
	 */
	public function __construct() {
		$this->load_dependencies();
	}

	/**
	 * Load the required dependencies for this plugin.
	 *
	 * Include the following files that make up the plugin:
	 *
	 * - GDPR_WP_Loader. Orchestrates the hooks of the plugin.
	 * - GDPR_WP_i18n. Defines internationalization functionality.
	 * - GDPR_WP_Admin. Defines all hooks for the admin area.
	 * - GDPR_WP_Public. Defines all hooks for the public side of the site.
	 *
	 * Create an instance of the loader which will be used to register the hooks
	 * with WordPress.
	 *
	 * @since    0.9
	 * @access   private
	 */
	private function load_dependencies() {

		/**
		 * The class responsible for orchestrating the actions and filters of the
		 * core plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-gdpr-wp-templates.php';

		$this->template = new GDPR_WP_Templates();

	}

	public function send( $user, $type, $args = array(), $attachments = array() ) {
		if ( ! is_a( $user, 'WP_User' ) ) {
			if ( ! is_int( $user ) ) {
				return;
			}
			$user = get_user_by( 'ID', $user );
		}

		$possible_types = apply_filters( 'gdpr_wp_notification_types', array(
			'forget' => esc_html__( 'Confirm account deletion', 'gdpr-wp' ),
			'forgot' => esc_html__( 'You account has been deleted', 'gdpr-wp' ),
			'data-breach' => esc_html__( 'Confirm Data Breach Request', 'gdpr-wp' ),
			'data-breach-export' => esc_html__( 'Data Breach Export', 'gdpr-wp' ),
		) );

		if ( ! in_array( $type, array_keys( $possible_types ), true ) ) {
			return;
		}

		$args = apply_filters( 'gdpr_wp_notification_args', $args );
		$content = $this->template->get_template_html( 'email/' . $type . '.php', $args );
		return wp_mail( $user->user_email,
			$possible_types[$type],
			$content,
			array( 'Content-Type: text/html; charset=UTF-8' ),
			( ! empty( $attachments ) ) ? $attachments : array()
		);
	}


}
